from django.apps import AppConfig


class MaintenanceConfig(AppConfig):
    name = 'Iuno.maintenance'
